from ase.build import bulk
from ase.optimize.bfgs import BFGS
from gpaw import GPAW
from pathlib import Path


def relax(atoms, calculator):
    calc = GPAW(**calculator)
    atoms.calc = calc

    opt = BFGS(atoms)
    opt.run(fmax=0.01)
    return atoms


def calculate_gs(atoms, calculator):
    calc = GPAW(**calculator)
    atoms.calc = calc
    atoms.get_potential_energy()
    path = Path('gs.gpw')
    calc.write(path)
    return path


def bandpath(atoms):
    return atoms.cell.bandpath(density=20)


def calculate_bs(gpw, bandpath):
    gscalc = GPAW(gpw)
    calc = gscalc.fixed_density(kpts=bandpath, txt='bs.txt',
                                symmetry='off')
    bs = calc.band_structure()
    return bs


def calculate_gs_cp2k(atoms):
    from ase.calculators.cp2k import CP2K

    calc = CP2K()
    atoms.calc = calc
    atoms.get_potential_energy()

