import taskblaster as tb


@tb.workflow
class MyWorkflow:
    atoms = tb.var()
    calculator = tb.var(default=dict(
        mode='pw', kpts={'density': 2}, txt='gpaw.txt'))

    @tb.task
    def relax(self):
        return tb.node('relax', atoms=self.atoms,
                       calculator=self.calculator)

    @tb.task
    def groundstate(self):
        return tb.node('calculate_gs', atoms=self.relax,
                       calculator=self.calculator)

    @tb.task
    def groundstate_cp2k(self):
        return tb.node('calculate_gs_cp2k', atoms=self.relax)

    @tb.task
    def bandpath(self):
        return tb.node('bandpath', atoms=self.relax)

    @tb.task
    def bandstructure(self):
        return tb.node('calculate_bs', bandpath=self.bandpath,
                       gpw=self.groundstate)



def workflow(runner):
    from ase.build import bulk
    atoms = bulk('Si')
    wf = MyWorkflow(atoms=atoms)
    runner.run_workflow(wf)
